@@ -50,10 +50,10 @@
 /* VOID:POINTER,BOOLEAN (./yelp-marshal.list:1) */
 void
 yelp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_BOOLEAN) (gpointer     data1,
@@ -91,10 +91,10 @@ yelp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
 /* VOID:STRING,INT (./yelp-marshal.list:4) */
 void
 yelp_marshal_VOID__STRING_INT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
@@ -130,10 +130,10 @@ yelp_marshal_VOID__STRING_INT (GClosure     *closure,
 /* BOOLEAN:POINTER,BOOLEAN (./yelp-marshal.list:6) */
 void
 yelp_marshal_BOOLEAN__POINTER_BOOLEAN (GClosure     *closure,
-                                       GValue       *return_value,
+                                       GValue       *return_value G_GNUC_UNUSED,
                                        guint         n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER_BOOLEAN) (gpointer     data1,
